@@ -1,5 +1,5 @@
 package ParentSchema::Result::Foo;
-our $VERSION = '2.00000_2';
+our $VERSION = '2.00100';
 use parent 'DBIx::Class';
 use strict;
 use warnings;
@@ -8,7 +8,12 @@ __PACKAGE__->load_components('Core');
 
 __PACKAGE__->table('Foo');
 
-__PACKAGE__->add_columns(qw/ id bar_id /);
+__PACKAGE__->add_columns(
+   id => {
+      is_numeric => 1,
+   },
+   'bar_id'
+);
 
 __PACKAGE__->set_primary_key('id');
 
